@@ -1,5 +1,5 @@
 package Bot::Cobalt::Core;
-$Bot::Cobalt::Core::VERSION = '0.017004';
+$Bot::Cobalt::Core::VERSION = '0.017005';
 ## This is the core Syndicator singleton.
 
 use strictures 2;
@@ -230,7 +230,11 @@ sub init {
      },
   );
 
-  unless ($self->detached) {
+  if ($self->detached) {
+    # Presumably our frontend closed these
+    open STDERR, '>>', $logfile or die $!;
+    open STDOUT, '>>', $logfile or die $!;
+  } else {
     $self->log->output->add(
       'screen' => {
         type => 'Term',
