@@ -1,9 +1,7 @@
 package Bot::Cobalt::Plugin::WWW;
-$Bot::Cobalt::Plugin::WWW::VERSION = '0.017004';
-
-
+$Bot::Cobalt::Plugin::WWW::VERSION = '0.017005';
+use v5.10;
 use strictures 2;
-use 5.10.1;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
